@@ -1,6 +1,6 @@
 #ifndef NETWORK_H
 #define NETWORK_H
 
-#define PORT 1504
-#define HOST "192.168.2.14"
+#define PORT 1505
+#define HOST "projects.cs.illinois.edu"
 #endif // NETWORK_H
